#!/bin/bash
#
# Script de resolución de problemas relacionados con la actualización automática de los clientes.

SCRIPTURL="http://f0/apt-fix/apt-fix.sh"
SCRIPTPATH="/var/cache/cga-apt/apt-fix.sh"
META="guadalinexedu-educacion-tic-aula20"
LOG="logger -i -t CGA-APT --"
ERRORMSG="Ha ocurrido un error al ejecutar el script de arreglos $SCRIPTPATH."
CGA_SECURE_APT="/var/lock/cga-apt.lock"

export PATH=/usr/bin:/usr/sbin:/sbin:/bin
export DEBIAN_FRONTEND=noninteractive

#Actualiza el sistema a la vieja usanza.
cgaUpdate ()
{
	apt-get -qq update
	touch $CGA_SECURE_APT
	dpkg --configure -a
	apt-get -y -f install --force-yes
	apt-get -uyd -qq install $META
	rm -f $CGA_SECURE_APT
}

# Baja el script de arreglos del f0 y lo ejecuta.
cgaGetFixer ()
{
        TMPFILE=$(mktemp /tmp/cga-apt.XXXXX)
        MD5ORIG=$(md5sum $SCRIPTPATH | cut -f1 -d' ')

        wget $SCRIPTURL -o /dev/null -O $TMPFILE || return 0
        TMPMD5=$(md5sum $TMPFILE | cut -f1 -d' ')

        if [ "$MD5ORIG" != "$TMPMD5" ]
        then
                # No son el mismo archivo, se copia a su sitio y se ejecuta.
                cp -f $TMPFILE $SCRIPTPATH
                chmod +x $SCRIPTPATH
        fi

        rm -f $TMPFILE

	return 1
}

# Ejecuta el "arreglador" y comprueba el código de salida.
# salida = 0 correcto
# salida != 0 error.

cgaExecFixer ()
{
        [ -x $SCRIPTPATH ] && $SCRIPTPATH
        ERRCOD=$?
        [ $ERRCOD -eq 0 ] || $LOG $ERRORMSG
}

# Inicio del script

$LOG "Procediendo a actualizar el sistema."
$LOG "Obteniendo cga-fix.sh desde $SCRIPTURL"
cgaGetFixer || $LOG "No se pudo descargar apt-fix.sh"

$LOG "Ejecutando el script $SCRIPTPATH"
cgaExecFixer

$LOG "Actualizando el sistema..."
cgaUpdate
$LOG "Actualizacion finalizada"


exit 0

